#
# spec file for package python-Fiona
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-Fiona
Version:        1.9.1
Release:        1.9
Summary:        Module for reading and writing spatial data files
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/Toblerity/Fiona
Source:         https://files.pythonhosted.org/packages/source/F/Fiona/Fiona-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gdal
BuildRequires:  libgdal-devel
BuildRequires:  proj
BuildRequires:  proj-devel
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 17
Requires:       python-click >= 4.0
Requires:       python-click-plugins >= 1.0
Requires:       python-cligj
Requires:       python-munch
Requires:       python-six >= 1.7
Recommends:     python-Shapely
Recommends:     python-boto3
Recommends:     python-certifi
# SECTION test requirements
BuildRequires:  %{python_module Shapely}
BuildRequires:  %{python_module attrs >= 17}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module click >= 4.0}
BuildRequires:  %{python_module click-plugins >= 1.0}
BuildRequires:  %{python_module cligj}
BuildRequires:  %{python_module munch}
BuildRequires:  %{python_module pyproj}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module six >= 1.7}
# /SECTION
%ifpython3
Recommends:     fiona-fio
%endif
%python_subpackages

%description
Fiona is OGR's spatial data API for Python programmers.

%package     -n fiona-fio
Summary:        Program for reading and writing spatial data files
Group:          Productivity/Scientific/Other
Requires:       python3-Fiona = %{version}
Conflicts:      fio
BuildArch:      noarch

%description -n fiona-fio
Command-line interface for reading and writing spatial data
using OGR's Fiona package.

%prep
%autosetup -p1 -n Fiona-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# The following require network
skiptests="wheel or test_open_zip_https or test_open_http or test_collection_http or test_collection_zip_http"
# Reason for this failure not recorded
skiptests="$skiptests or GPSTrackMaker"
# December 2022: test_no_append_driver_cannot_append has started failing for FlatGeobuf and GeoJSONSeq only
skiptests="$skiptests or (test_no_append_driver_cannot_append and (FlatGeobuf or GeoJSONSeq))"

mv fiona fiona_temp
export GDAL_DATA=$(pkg-config --variable=datadir gdal)
export PROJ_LIB=$(pkg-config --variable=datadir proj)
export LANG=en_US.UTF-8
%pytest_arch -rs -k "not ($skiptests)"
mv fiona_temp fiona

%files %{python_files}
%doc CHANGES.txt CREDITS.txt README.rst
%license LICENSE.txt
%{python_sitearch}/fiona
%{python_sitearch}/Fiona-%{version}*-info

%files -n fiona-fio
%license LICENSE.txt
%{_bindir}/fio

%changelog
* Sun Feb 26 2023 Matej Cepl <mcepl@suse.com>
- Update to 1.9.1:
  The 1.9.0 release revealed a few bugs. Here are the ones we
  felt should be squished immediately.
  - Log a warning message when identically named fields are
    encountered (#1201).
  - Avoid dependence on listdir order in tests (#1193).
  - Prevent empty geometries arrays from appearing in
    __geo_interface__ (#1197).
  - setuptools added to pyproject.toml. Its pkg_resources module
    is used by the CLI (#1191).
- Update to 1.9.0:
  - Deprecations
  - The precision keyword argument of
    fiona.transform.transform_geom is deprecated and will be
    removed in version 2.0.
  - The fiona.drivers() function has been deprecated and
    will be removed in version 2.0. It should be replaced by
    fiona.Env().
  - The new fiona.meta module will be renamed to fiona.drivers
    in version 2.0.
  - The major new features are:
  - A new CRS class identical to Rasterio's.
  - New Feature and Geometry classes. These are returned
    instead of dicts but are compatible with version 1.8's
    dicts.
  - Access to format driver metadata.
  Please see the change log entries for 1.9 pre-releases at
  https://github.com/Toblerity/Fiona/releases to see a complete
  list of new features and bug fixes.
* Thu Dec  1 2022 John Vandenberg <jayvdb@gmail.com>
- Skip two failing tests
* Thu Sep 15 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v1.8.21
  * Driver mode support tests have been made more general and less
    susceptible to driver quirks involving feature fields and
    coordinate values.
  * OSError is raised on attempts to open a dataset in a Python
    file object in "a" mode.
  * Upgrade attrs, cython, etc to open up Python 3.10 support
  * Allow FieldSkipLogFilter to handle exception messages as well as strings
  * Clean up VSI files left by MemoryFileBase
  * Hard-coded "utf-8" collection encoding has been removed
- from v1.8.20
  * Allow use with click 8 and higher
- from v1.8.19
  * In fiona/env.py the GDAL data path is now configured using
    set_gdal_config instead by setting the GDAL_DATA environment variable
  * Spurious iterator reset warnings have been eliminated.
- from v1.8.18
  * The precision option of transform has been fixed for the case of
    GeometryCollections
  * Added missing --co (creation) option to fio-load
  * If the certifi package can be imported, its certificate store
    location will be passed to GDAL during import of fiona._env unless
    CURL_CA_BUNDLE is already set.
  * Warn when feature fields named "" are found
- from v1.8.17
  * To fix issue #952 the fio-cat command no longer cuts feature
    geometries at the anti-meridian by default. A --cut-at-antimeridian
    option has been added to allow cutting of geometries in a geographic
    destination coordinate reference system.
- from v1.8.16
  * More OGR errors and warnings arising in calls to GDAL C API functions
    are surfaced.
  * A circular import introduced in some cases in 1.8.15 has been fixed
- from v1.8.15
  * Change shim functions to not return tuples
  * Raise a Python exception when VSIFOpenL fails.
- from v1.8.14
  * When creating a new Collection in a MemoryFile with a default (random) name
    Fiona will attempt to use a format driver-supported file extension.
    When initializing a MemoryFile with bytes of data formatted for a vector
    driver that requires a certain file name or extension, the user should
    continue to pass an appropriate filename and/or extension.
  * Read support for FlatGeobuf has been enabled in the drvsupport module.
  * The MemoryFile implementation has been improved so that it can support multi-part
    S3 downloads (#906). This is largely a port of code from rasterio.
  * Axis ordering for results of fiona.transform was wrong when CRS were
    passed in the "EPSG:dddd" form.
  * Allow implicit access to the only dataset in a ZipMemoryFile.
    The path argument of ZipMemoryFile.open() is now optional
  * Improve support for datetime types: support milliseconds, timezones
    and improve warnings if type is not supported by driver
  * Fix "Failed to commit transaction" TransactionError for FileGDB driver.
  * Load GDAL DLL dependencies on Python 3.8+ / Windows with add_dll_directory()
  * Do not require optional properties
  * Ensure that slice does not overflow available data
  * Resolve issue when "ERROR 4: Unable to open EPSG support file gcs.csv."
    is raised on importing fiona.
  * Resolve issue resulting in possible mixed up fields names (affecting
    only DXF, GPX, GPSTrackMacker and DGN driver)
  * Ensure crs_wkt is passed when writing to MemoryFile
* Sat Mar 14 2020 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 1.18.13.post1
  + improve binary wheel compatibility with shapely 1.7.0
  + All update are referenced online or in the package
    https://github.com/Toblerity/Fiona/blob/master/CHANGES.txt
- Fix tests error with proj.db (datadir instead libdir)
- Make only python3 as we don't have anymore python2-pyproj
- spec-cleaner
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Fix dependencies.
- Enable unit tests
- Ran spec-cleaner
* Mon Apr  1 2019 Todd R <toddrme2178@gmail.com>
- Split executable into own module to avoid conflicts with fio.
  fio is a Linux Kernel project so we probably don't want to make
  fiona conflict with it completely.
* Fri Mar 29 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description. Use noun phrase in summary.
* Thu Mar 28 2019 Todd R <toddrme2178@gmail.com>
- Update to last version 1.8.6
  * The advertisement for JSON driver enablement in 1.8.5 was false (#176), but
    in this release they are ready for use.
- Update to last version 1.8.5
  * GDAL seems to work best if GDAL_DATA is set as early as possible. Ideally it
    is set when building the library or in the environment before importing
    Fiona, but for wheels we patch GDAL_DATA into os.environ when fiona.env
    is imported. This resolves #731.
  * A combination of bugs which allowed .cpg files to be overlooked has been
    fixed (#726).
  * On entering a collection context (Collection.__enter__) a new anonymous GDAL
    environment is created if needed and entered. This makes `with
    fiona.open(...) as collection:` roughly equivalent to `with fiona.open(...)
    as collection, Env():`. This helps prevent bugs when Collections are created
    and then used later or in different scopes.
  * Missing GDAL support for TopoJSON, GeoJSONSeq, and ESRIJSON has been enabled
    (#721).
  * A regression in handling of polygons with M values (#724) has been fixed.
  * Per-feature debug logging calls in OGRFeatureBuilder methods have been
    eliminated to improve feature writing performance (#718).
  * Native support for datasets in Google Cloud Storage identified by "gs"
    resource names has been added (#709).
  * Support has been added for triangle, polyhedral surface, and TIN geometry
    types (#679).
  * Notes about using the MemoryFile and ZipMemoryFile classes has been added to
    the manual (#674).
* Wed Mar  6 2019 Martin Pluskal <mpluskal@suse.com>
- Rename package to python-Fiona
- Install license and documentation
* Wed Mar  6 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to last version 1.8.4
  + There are no known breaking changes in 1.8.0. Python warnings
    should be expected in several cases of class and method
    deprecation.
  + The fiona.drivers() context manager is being replaced by
    fiona.Env(), which also registers format drivers and has the
    same properties as the GDAL configuration manager in Rasterio.
  + Collection slicing will be disallowed in a future version of
    Fiona to remove the confusion between mapping and list semantics
    for Collection objects. Code such as
    fiona.open(“example.shp”)[1:10]
    should be changed to list(fiona.open(“example.shp”))[1:10].
- Packaging: Minimal spec-cleaner
  + Remove unneeded requires: python
* Sun Oct 21 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to last version 1.7.13
  Including fix for boo#1107387
- Packaging:
  + redone spec with py2pac singlespec
  + package is not noarch
  + /usr/bin/fio is distributed only for python3
* Tue Jun  9 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- initial packaging (1.5.1)
